randfacts is a python library that generates random facts. You can use ```randfacts.getFact()``` to return a random fun fact.

Example:
```python
import randfacts
x = randfacts.getFact()
print(x)
```
will print a random fact like:
```Penguins can't taste sweet or savory flavors, only sour and salty ones```
